| Title: | Animated icons for R Markdown and Shiny |
|---|---|
| Description: | This package allows easy insertion of animated icons into R Markdown html outputs. |
| Authors: | Emi Tanaka [aut, cre] |
| Maintainer: | Emi Tanaka <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-07-05 08:34:06 UTC |
| Source: | https://github.com/emitanaka/anicon |
Insert icon from academicons v1.8.0
aia(name = "academia", size = 1, position = c(0, 0, 0, 0), grow = 0, fixed_width = FALSE, animate = "flash", speed = "normal", anitype = "repeat", rtext = "", ltext = "", rotate = 0, flip = "none", border = FALSE, color = NULL, colour = color, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)aia(name = "academia", size = 1, position = c(0, 0, 0, 0), grow = 0, fixed_width = FALSE, animate = "flash", speed = "normal", anitype = "repeat", rtext = "", ltext = "", rotate = 0, flip = "none", border = FALSE, color = NULL, colour = color, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)
name |
A string indicating the icon name. |
size |
Size of the icon relative to font size. Options are 1, lg (133 percent), xs (75 percent), sm (87.5 percent), 2, 3, 4, 5, 7 or 10. |
position |
A numerical vector of length 4 specifying the value to move up, down, left and right. |
grow |
Numerical value to grow (or shrink for negative values) without changing or moving the container. |
fixed_width |
If TRUE, the icon is set to a fixed width |
animate |
'bounce', 'burst', 'falling', 'flash', 'float', 'horizontal', 'passing', 'passing-reverse', 'pulse', 'ring', 'shake', 'spin', 'tada', 'vertical', or 'wrench' |
speed |
'normal', 'fast', or 'slow' |
anitype |
'repeat', 'hover', or 'parent-hover' |
rtext |
The text to be inserted on the right side. |
ltext |
The text to be inserted on the left side. |
rotate |
Numerical value for degree of rotation. |
flip |
'none', 'horizontal', 'vertical'. |
border |
If TRUE, draws a border around the icon. |
color |
Colour to be given to the icon |
colour |
Colour to be given to the icon |
bgcolor |
Colour to be given to the background |
bgcolour |
Colour to be given to the background |
iother |
Character vector of other parameters directly added to the icon classes, e.g. fa-pull-left, fa-pull-right. |
sother |
Character vector of other parameters directly added to the style classes. |
dother |
Character vector of other parameters directly added to the data-fa-transform classes, e.g. shrink-8, grow-2 |
Insert your own image and make it animated.
cia(src, height = NULL, width = NULL, size = 1, position = c(0, 0, 0, 0), grow = 0, animate = "flash", speed = "normal", anitype = "repeat", rotate = 0, flip = "none", rtext = "", ltext = "", border = FALSE, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)cia(src, height = NULL, width = NULL, size = 1, position = c(0, 0, 0, 0), grow = 0, animate = "flash", speed = "normal", anitype = "repeat", rotate = 0, flip = "none", rtext = "", ltext = "", border = FALSE, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)
src |
A url or path of image/gif to animate. |
height |
Height of the image that can be specified in percentage or pixels. This cannot be defined if size or grow is defined. |
width |
Width of the image that can be specified in percentage or pixels. This cannot be defined if size or grow is defined. |
size |
Size of the icon relative to font size. Options are lg (133 percent), xs (75 percent), sm (87.5 percent) or a positive number. |
position |
A numerical vector of length 4 specifying the value to move up, down, left and right. NOT IMPLEMENTED YET. |
grow |
Numerical value to grow (or shrink for negative values) without changing or moving the container. |
animate |
'bounce', 'burst', 'falling', 'flash', 'float', 'horizontal', 'passing', 'passing-reverse', 'pulse', 'ring', 'shake', 'spin', 'tada', 'vertical', 'wrench', or use FALSE not to animate. |
speed |
'normal', 'fast', or 'slow' |
anitype |
'repeat', 'hover', or 'parent-hover' |
rotate |
Numerical value for degree of rotation. |
flip |
'none', 'horizontal', 'vertical'. |
rtext |
The text to be inserted on the right side. |
ltext |
The text to be inserted on the left side. |
border |
If TRUE, draws a border around the icon. |
bgcolor, bgcolour
|
Colour to be given to the background |
sother |
Character vector of other parameters directly added to the style classes. |
Insert animated icon from font awesome
faa(name = "font-awesome", size = 1, position = c(0, 0, 0, 0), grow = 0, fixed_width = FALSE, animate = "flash", speed = "normal", anitype = "repeat", rtext = "", ltext = "", rotate = 0, flip = "none", border = FALSE, color = NULL, colour = color, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)faa(name = "font-awesome", size = 1, position = c(0, 0, 0, 0), grow = 0, fixed_width = FALSE, animate = "flash", speed = "normal", anitype = "repeat", rtext = "", ltext = "", rotate = 0, flip = "none", border = FALSE, color = NULL, colour = color, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)
name |
A string indicating the icon name. |
size |
Size of the icon relative to font size. Options are 1, lg (133 percent), xs (75 percent), sm (87.5 percent), 2, 3, 4, 5, 7 or 10. |
position |
A numerical vector of length 4 specifying the value to move up, down, left and right. |
grow |
Numerical value to grow (or shrink for negative values) without changing or moving the container. |
fixed_width |
If TRUE, the icon is set to a fixed width |
animate |
'bounce', 'burst', 'falling', 'flash', 'float', 'horizontal', 'passing', 'passing-reverse', 'pulse', 'ring', 'shake', 'spin', 'tada', 'vertical', or 'wrench' |
speed |
'normal', 'fast', or 'slow' |
anitype |
'repeat', 'hover', or 'parent-hover' |
rtext |
The text to be inserted on the right side. |
ltext |
The text to be inserted on the left side. |
rotate |
Numerical value for degree of rotation. |
flip |
'none', 'horizontal', 'vertical'. |
border |
If TRUE, draws a border around the icon. |
color, colour
|
Colour to be given to the icon |
bgcolor, bgcolour
|
Colour to be given to the background |
iother |
Character vector of other parameters directly added to the icon classes, e.g. fa-pull-left, fa-pull-right. |
sother |
Character vector of other parameters directly added to the style classes. |
dother |
Character vector of other parameters directly added to the data-fa-transform classes, e.g. shrink-8, grow-2 |
Insert animated text
nia(text = "anicon", size = 1, position = c(0, 0, 0, 0), grow = 0, fixed_width = FALSE, animate = "flash", speed = "normal", anitype = "repeat", rotate = 0, flip = "none", border = FALSE, color = NULL, colour = color, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)nia(text = "anicon", size = 1, position = c(0, 0, 0, 0), grow = 0, fixed_width = FALSE, animate = "flash", speed = "normal", anitype = "repeat", rotate = 0, flip = "none", border = FALSE, color = NULL, colour = color, bgcolor = NULL, bgcolour = bgcolor, iother = NULL, sother = NULL, dother = NULL)
text |
A string to animate. |
size |
Size of the icon relative to font size. Options are 1, lg (133 percent), xs (75 percent), sm (87.5 percent), 2, 3, 4, 5, 7 or 10. |
position |
A numerical vector of length 4 specifying the value to move up, down, left and right. |
grow |
Numerical value to grow (or shrink for negative values) without changing or moving the container. |
fixed_width |
If TRUE, the icon is set to a fixed width |
animate |
'bounce', 'burst', 'falling', 'flash', 'float', 'horizontal', 'passing', 'passing-reverse', 'pulse', 'ring', 'shake', 'spin', 'tada', 'vertical', or 'wrench' |
speed |
'normal', 'fast', or 'slow' |
anitype |
'repeat' or 'hover' |
rotate |
Numerical value for degree of rotation. |
flip |
'none', 'horizontal', 'vertical'. |
border |
If TRUE, draws a border around the icon. |
color, colour
|
Colour to be given to the icon |
bgcolor, bgcolour
|
Colour to be given to the background |
iother |
Character vector of other parameters directly added to the icon classes, e.g. fa-pull-left, fa-pull-right. |
sother |
Character vector of other parameters directly added to the style classes. |
dother |
Character vector of other parameters directly added to the data-fa-transform classes, e.g. shrink-8, grow-2 |